@@ -86,9 +86,10 @@ class MangoxoAlbumExtractor(MangoxoExtractor):
             "album": {
                 "id": "lzVOv1Q9",
                 "name": "re:池永康晟 Ikenaga Yasunari 透出古朴",
-                "date": "2019.3.22 14:42",
+                "date": "dt:2019-03-22 14:42:00",
                 "description": str,
             },
+            "id": int,
             "num": int,
             "count": 65,
         },
@@ -107,29 +108,34 @@ class MangoxoAlbumExtractor(MangoxoExtractor):
 
         yield Message.Version, 1
         yield Message.Directory, data
-        for data["num"], image in enumerate(imgs, 1):
-            yield Message.Url, image, text.nameext_from_url(image, data)
+
+        data["extension"] = None
+        for data["num"], path in enumerate(imgs, 1):
+            data["id"] = text.parse_int(text.extract(path, "=", "&")[0])
+            url = self.root + "/external/" + path.rpartition("url=")[2]
+            yield Message.Url, url, text.nameext_from_url(url, data)
 
     def metadata(self, page):
         """Return general metadata"""
         title, pos = text.extract(page, '<title>', '</title>')
-        count, pos = text.extract(page, 'id="pic-count">', '<', pos)
-        cover, pos = text.extract(page, ' src="', '"', pos)
+        _    , pos = text.extract(page, 'class="desc"', '', pos)
         cid  , pos = text.extract(page, '//www.mangoxo.com/channel/', '"', pos)
         cname, pos = text.extract(page, '>', '<', pos)
+        count, pos = text.extract(page, 'id="pic-count">', '<', pos)
+        cover, pos = text.extract(page, ' src="', '"', pos)
         date , pos = text.extract(page, '</i>', '<', pos)
         descr, pos = text.extract(page, '<pre>', '</pre>', pos)
 
         return {
             "channel": {
                 "id": cid,
-                "name": text.unescape(cname),
+                "name": text.unescape(cname.strip()),
                 "cover": cover,
             },
             "album": {
                 "id": self.album_id,
                 "name": text.unescape(title),
-                "date": date.strip(),
+                "date": text.parse_datetime(date.strip(), "%Y.%m.%d %H:%M"),
                 "description": text.unescape(descr),
             },
             "count": text.parse_int(count),
