@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright 2019-2020 Mike Fährmann
+# Copyright 2019-2021 Mike Fährmann
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -23,6 +23,7 @@ class PatreonExtractor(Extractor):
     directory_fmt = ("{category}", "{creator[full_name]}")
     filename_fmt = "{id}_{title}_{num:>02}.{extension}"
     archive_fmt = "{id}_{num}"
+    browser = "firefox"
     _warning = True
 
     def items(self):
@@ -34,12 +35,14 @@ class PatreonExtractor(Extractor):
             PatreonExtractor._warning = False
 
         for post in self.posts():
+
+            if not post.get("current_user_can_view", True):
+                self.log.warning("Not allowed to view post %s", post["id"])
+                continue
             post["num"] = 0
             hashes = set()
 
             yield Message.Directory, post
-            yield Message.Metadata, post
-
             for kind, url, name in itertools.chain(
                 self._images(post),
                 self._attachments(post),
@@ -113,14 +116,17 @@ class PatreonExtractor(Extractor):
         """Process and extend a 'post' object"""
         attr = post["attributes"]
         attr["id"] = text.parse_int(post["id"])
-        attr["images"] = self._files(post, included, "images")
-        attr["attachments"] = self._files(post, included, "attachments")
-        attr["date"] = text.parse_datetime(
-            attr["published_at"], "%Y-%m-%dT%H:%M:%S.%f%z")
-        user = post["relationships"]["user"]
-        attr["creator"] = (
-            self._user(user["links"]["related"]) or
-            included["user"][user["data"]["id"]])
+
+        if post.get("current_user_can_view", True):
+            attr["images"] = self._files(post, included, "images")
+            attr["attachments"] = self._files(post, included, "attachments")
+            attr["date"] = text.parse_datetime(
+                attr["published_at"], "%Y-%m-%dT%H:%M:%S.%f%z")
+            user = post["relationships"]["user"]
+            attr["creator"] = (
+                self._user(user["links"]["related"]) or
+                included["user"][user["data"]["id"]])
+
         return attr
 
     @staticmethod
@@ -242,9 +248,9 @@ class PatreonCreatorExtractor(PatreonExtractor):
 
         creator_id = query.get("u")
         if creator_id:
-            url = "{}/user?u={}".format(self.root, creator_id)
+            url = "{}/user/posts?u={}".format(self.root, creator_id)
         else:
-            url = "{}/{}".format(self.root, self.creator.lower())
+            url = "{}/{}/posts".format(self.root, self.creator)
 
         page = self.request(url, notfound="creator").text
         campaign_id = text.extract(page, "/campaign/", "/")[0]
