@@ -47,7 +47,9 @@ class WebtoonsEpisodeExtractor(WebtoonsExtractor):
         (("https://www.webtoons.com/en/comedy/safely-endangered"
           "/ep-572-earth/viewer?title_no=352&episode_no=572"), {
             "url": "11041d71a3f92728305c11a228e77cf0f7aa02ef",
-            "content": "4f7701a750368e377d65900e6e8f64a5f9cb9c86",
+            "content": ("1748c7e82b6db910fa179f6dc7c4281b0f680fa7",
+                        "42055e44659f6ffc410b3fb6557346dfbb993df3",
+                        "49e1f2def04c6f7a6a3dacf245a1cd9abe77a6a9"),
             "count": 5,
         }),
     )
