@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright 2017-2020 Mike Fährmann
+# Copyright 2017-2021 Mike Fährmann
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -98,8 +98,9 @@ def build_parser():
     )
     general.add_argument(
         "-i", "--input-file",
-        dest="inputfile", metavar="FILE",
-        help="Download URLs found in FILE ('-' for stdin)",
+        dest="inputfiles", metavar="FILE", action="append",
+        help=("Download URLs found in FILE ('-' for stdin). "
+              "More than one --input-file can be specified"),
     )
     general.add_argument(
         "--cookies",
@@ -135,6 +136,11 @@ def build_parser():
         dest="list_urls", action="count",
         help="Print URLs instead of downloading",
     )
+    output.add_argument(
+        "-G", "--resolve-urls",
+        dest="list_urls", action="store_const", const=128,
+        help="Print URLs instead of downloading; resolve intermediary URLs",
+    )
     output.add_argument(
         "-j", "--dump-json",
         dest="jobtype", action="store_const", const=job.DataJob,
@@ -145,6 +151,11 @@ def build_parser():
         dest="jobtype", action="store_const", const=job.SimulationJob,
         help="Simulate data extraction; do not download anything",
     )
+    output.add_argument(
+        "-E", "--extractor-info",
+        dest="jobtype", action="store_const", const=job.InfoJob,
+        help="Print extractor defaults and settings",
+    )
     output.add_argument(
         "-K", "--list-keywords",
         dest="jobtype", action="store_const", const=job.KeywordJob,
