@@ -1,7 +1,7 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 
-# Copyright 2015-2020 Mike Fährmann
+# Copyright 2015-2021 Mike Fährmann
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -14,6 +14,7 @@ import unittest
 import io
 import random
 import string
+import datetime
 import http.cookiejar
 
 sys.path.insert(0, os.path.dirname(os.path.dirname(os.path.abspath(__file__))))
@@ -267,6 +268,7 @@ class TestFormatter(unittest.TestCase):
         "n": None,
         "s": " \n\r\tSPACE    ",
         "u": "%27%3C%20/%20%3E%27",
+        "t": 1262304000,
         "name": "Name",
         "title1": "Title",
         "title2": "",
@@ -289,6 +291,9 @@ class TestFormatter(unittest.TestCase):
         self._run_test("{a!S}", self.kwdict["a"])
         self._run_test("{l!S}", "a, b, c")
         self._run_test("{n!S}", "")
+        self._run_test("{t!d}", datetime.datetime(2010, 1, 1))
+        self._run_test("{t!d:%Y-%m-%d}", "2010-01-01")
+
         with self.assertRaises(KeyError):
             self._run_test("{a!q}", "hello world")
 
@@ -456,6 +461,16 @@ class TestOther(unittest.TestCase):
         self.assertSequenceEqual(
             list(util.unique([1, 2, 1, 3, 2, 1])), [1, 2, 3])
 
+    def test_unique_sequence(self):
+        self.assertSequenceEqual(
+            list(util.unique_sequence("")), "")
+        self.assertSequenceEqual(
+            list(util.unique_sequence("AABBCC")), "ABC")
+        self.assertSequenceEqual(
+            list(util.unique_sequence("ABABABCAABBCC")), "ABABABCABC")
+        self.assertSequenceEqual(
+            list(util.unique_sequence([1, 2, 1, 3, 2, 1])), [1, 2, 1, 3, 2, 1])
+
     def test_raises(self):
         func = util.raises(Exception)
         with self.assertRaises(Exception):
@@ -469,6 +484,19 @@ class TestOther(unittest.TestCase):
         with self.assertRaises(ValueError):
             func(3)
 
+    def test_generate_token(self):
+        tokens = set()
+        for _ in range(100):
+            token = util.generate_token()
+            tokens.add(token)
+            self.assertEqual(len(token), 16 * 2)
+            self.assertRegex(token, r"^[0-9a-f]+$")
+        self.assertGreaterEqual(len(tokens), 99)
+
+        token = util.generate_token(80)
+        self.assertEqual(len(token), 80 * 2)
+        self.assertRegex(token, r"^[0-9a-f]+$")
+
     def test_combine_dict(self):
         self.assertEqual(
             util.combine_dict({}, {}),
